Agent skill · Design & Presentation

stencil-convolution

Expert skill for optimized stencil and convolution pattern implementations on GPU. Design tiled stencil algorithms with halos, implement 2D/3D convolution kernels, optimize boundary condition handling, apply temporal blocking techniques, generate separable filter implementations, and profile stencil memory bandwidth.

a5c-aigithub.com/a5c-aiGitHub ↗
claude-codecodexcan modify filesMIT
Install
npx skills add a5c-ai/babysitter --skill stencil-convolution --agent claude-code

Same command for any agent — swap --agent for codex, cursor, copilot.

Facts
Files in the skill folder: 2
SKILL.md size: 16 KB
Bundled scripts: none
Version: 1.0.0
Declared author: babysitter-sdk
Allowed tools: Bash(*)ReadWriteEditGlobGrepWebFetch
Path: library/specializations/gpu-programming/skills/stencil-convolution/SKILL.md
Open the folder on GitHub →
Where it comes from
Stars: 1,642
Language: JavaScript

Weekly change comes from our own snapshots, not the repository page — it measures attention, not adoption.

From the SKILL.md

# stencil-convolution You are **stencil-convolution** - a specialized skill for optimized stencil and convolution pattern implementations on GPU. This skill provides expert capabilities for scientific computing, image processing, and numerical simulations requiring neighborhood computations. ## Overview This skill enables AI-powered stencil and convolution operations including: - Designing tiled stencil algorithms with halos - Implementing 2D/3D convolution kernels - Optimizing boundary condition handling - Applying temporal blocking techniques - Generating separable filter implementations - Configuring shared memory tiling strategies - Profiling stencil memory bandwidth - Supporting multi-resolution stencils ## Prerequisites - NVIDIA CUDA Toolkit 11.0+ - GPU with compute capability 3.5+ - Understanding of memory coalescing patterns - Nsight Compute for memory analysis - Optional: cuDNN for optimized convolutions ## Capabilities ### 1. Basic 2D Stencil (5-Point Laplacian) ```cuda // Naive 5-point stencil (for comparison) __global__ void laplacian2D_naive( float* out, const float* in, int width, int height ) { int x = blockIdx.x * blockDim.x + threadIdx.x; int y = blockIdx.y * block

What's inside
Steps it walks through
  1. Overview
  2. Prerequisites
  3. Capabilities
  4. 1. Basic 2D Stencil (5-Point Laplacian)
  5. 2. Tiled Stencil with Shared Memory and Halo
  6. 3. Generic N-Point Stencil with Configurable Radius
  7. 4. 2D Convolution with Arbitrary Kernel
  8. 5. Separable Convolution (2-Pass for Performance)
  9. 6. 3D Stencil (7-Point Laplacian)
  10. 7. Temporal Blocking (Multi-Timestep)
  11. 8. Boundary Condition Patterns
  12. Best Practices
  13. Memory Access Patterns
  14. Tile Size Selection
Ships with 1 file
  • README.md
More from babysitter
All skills →
About this skill
What does the stencil-convolution skill do?

Expert skill for optimized stencil and convolution pattern implementations on GPU. Design tiled stencil algorithms with halos, implement 2D/3D convolution kernels, optimize boundary condition handling, apply temporal blocking techniques, generate separable filter implementations, and profile stencil memory bandwidth.

How do I install it?

Run `npx skills add a5c-ai/babysitter --skill stencil-convolution --agent claude-code` — it drops the skill into your project so the agent can pick it up. Swap the --agent value for codex, cursor or copilot if you use one of those.

Where does this skill come from?

From a5c-ai/babysitter, a repository with 1,642 stars. We read it straight from the repository tree rather than a submitted listing, so what you see here is what is actually published.

Is a popular skill a good skill?

Not necessarily. Stars measure attention, not adoption — a repository can trend for a week and be abandoned. That is why we show the weekly change from our own snapshots next to the total, instead of a single flattering number.

Keep going